"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.buildFile = exports.convertToTsContent = exports.toKeyValue = void 0;
const fs_1 = require("fs");
const camelcase_1 = __importDefault(require("camelcase"));
const prettier_1 = __importDefault(require("prettier"));
const path_1 = __importDefault(require("path"));
const toKeyValue = (classes) => {
    const fileContent = classes.reduce((classNames, className) => {
        classNames[camelcase_1.default(className)] = className;
        return classNames;
    }, {});
    return fileContent;
};
exports.toKeyValue = toKeyValue;
const convertToTsContent = (filename, content) => {
    const tsContent = `export const ${camelcase_1.default(filename)}Style = ${JSON.stringify(content)}`;
    const formattedContent = prettier_1.default.format(tsContent, {
        singleQuote: true,
        parser: 'typescript',
    });
    return formattedContent;
};
exports.convertToTsContent = convertToTsContent;
const buildFile = (cssFileName, classes) => {
    const dirname = path_1.default.dirname(cssFileName);
    const filename = path_1.default.basename(cssFileName, path_1.default.extname(cssFileName));
    const keyValues = exports.toKeyValue(classes);
    const tsContent = exports.convertToTsContent(filename, keyValues);
    fs_1.writeFileSync(`${dirname}/${filename}.style.ts`, tsContent);
};
exports.buildFile = buildFile;
